Enum parquet::errors::ParquetError [−]
Set of errors that can be produced during different operations in Parquet.
Variants
General(String)General Parquet error. Returned when code violates normal workflow of working with Parquet files.
NYI(String)"Not yet implemented" Parquet error. Returned when functionality is not yet available.
EOF(String)"End of file" Parquet error. Returned when IO related failures occur, e.g. when there are not enough bytes to decode.